@@ -1,12 +1,16 @@
 package Net::Twitter::OAuth;
-use Net::Twitter;
+use Moose;
 
 # use *all* digits for fBSD ports
-our $VERSION = '3.03000';
-
+our $VERSION = '3.03001';
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 
-sub new { shift; Net::Twitter->new(traits => [qw/Legacy OAuth/], @_) }
+extends  'Net::Twitter::Core';
+with map "Net::Twitter::Role::$_", qw/Legacy OAuth/;
+
+no Moose;
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
